# -*- coding: utf-8 -*-
# author: pengr
#               |_|               |_|


'''
通用数据处理工具

:copyright: (c) 2019 by pengr.
:license: GNU GENERAL PUBLIC LICENSE, see LICENSE for more details.
'''

__title__ = '通用数据处理工具'
__description__ = '通用数据处理工具'
__author__ = 'pengr'
__author_email__ = 'pengrui55555@163.com'
__license__ = 'Apache 2.0'
__copyright__ = 'Copyright 2019 Pengr'

from . import util
from .constants import non
from .reader import getCsvData, getXlsData
from .dataSet import DataSet
